@@ -2,7 +2,7 @@
 .\" First parameter, NAME, should be all caps
 .\" Second parameter, SECTION, should be 1-8, maybe w/ subsection
 .\" other parameters are allowed: see man(7), man(1)
-.TH LIQUID SECTION "September  6, 2010"
+.TH LIQUID SECTION "January 31, 2011"
 .\" Please adjust this date whenever revising the manpage.
 .\"
 .\" Some roff macros, for reference:
@@ -55,5 +55,5 @@ available via the Info system.
 .SH AUTHOR
 liquid was written by <upstream author>.
 .PP
-This manual page was written by maemo-sensors <maemo-sensors@cs.karelia.ru>,
+This manual page was written by nimnes <nimnes@gmail.com>,
 for the Debian project (but may be used by others).
