@@ -241,7 +241,7 @@ void Painter::drawPearl() {
     gradient.setColorAt(0.9, m_color.toRgb());
     gradient.setColorAt(0.95, QColor(0, 0, 0, 127));
     gradient.setColorAt(1, QColor(0, 0, 0, 0));
-    // painter.setRenderHint(QPainter::Antialiasing);
+    painter.setRenderHint(QPainter::Antialiasing);
     painter.setBrush(gradient);
     painter.setPen(Qt::NoPen);
     painter.drawEllipse(0, 0, bounds.width(), bounds.height());
@@ -295,7 +295,7 @@ void Painter::rollHandler() {
 }
 
 // Overloading paintEvent of widget
-void Painter::paintEvent(QPaintEvent *e) {
+void Painter::paintEvent(QPaintEvent*) {
     QPainter painter(this);
     painter.drawImage(0, 0 , *theImage);
     painter.drawPixmap(m_pos - QPointF(m_size/2, m_size/2), m_pearl_pixmap);
