@@ -162,7 +162,7 @@ QImage Filters::blurCircle(int i, int j, int r, QImage *image) {
 }
 
 // Checks boundaries of blur
-void Filters::checking(int i, int j, QImage *image) {
+void Filters::checking(int i, int j, QImage *) {
     if (i < radius)
         upperBorder = i;
     else
