@@ -58,6 +58,9 @@ MainWindow::MainWindow(QWidget *parent) :
     ui->toolBar->addAction(iceAct);    
     ui->toolBar->addAction(fullScreenAct);    
 
+    QTextCodec *codec = QTextCodec::codecForName("UTF8");
+    QTextCodec::setCodecForTr(codec);
+
     connect(errorHandler, SIGNAL(accFatalError()), SLOT(disableAccelerometer()));
     connect(painter, SIGNAL(disableAccelerometer()), SLOT(disableAccelerometer()));
     connect(painter, SIGNAL(activateAccelerometer()), SLOT(activateAccelerometer()));
@@ -73,8 +76,8 @@ MainWindow::~MainWindow()
 void MainWindow::confirmClearing() {
     if (!painter->isClean) {
         QMessageBox msgBox;
-        msgBox.setText("Clearing workspace");
-        msgBox.setInformativeText("Do you want to clear workspace?");
+        msgBox.setText(tr("Clearing workspace"));
+        msgBox.setInformativeText(tr("Do you want to clear workspace?"));
         msgBox.setStandardButtons(QMessageBox::Yes | QMessageBox::No );
         msgBox.setDefaultButton(QMessageBox::Yes);
 
@@ -140,6 +143,8 @@ void MainWindow::createActions() {
     toggleAcc->setChecked(true);
     connect(toggleAcc, SIGNAL(toggled(bool)), SLOT(toggleAccelerometer(bool)));
 
+    langAct = new QAction(tr("Language"), this);
+
     aboutAct = new QAction(tr("About program"), this);
     connect(aboutAct, SIGNAL(triggered()), SLOT(showAbout()));
 
@@ -158,7 +163,7 @@ void MainWindow::createMenus() {
     fileMenu->addAction(exitAct);
 
     modeMenu = ui->menubar->addMenu(tr("&Mode"));
-    modeMenu->addAction(toggleAcc);    
+    modeMenu->addAction(toggleAcc);
 
     helpMenu = ui->menubar->addMenu(tr("&Help"));
     helpMenu->addAction(aboutAct);
@@ -172,21 +177,21 @@ void MainWindow::showHelp() {
 
 // Shows dilog with information about application and developers
 void MainWindow::showAbout() {
-        QMessageBox::about(this, tr("About program"), tr(
-                "<div style='y-overflow:scroll;'>"
-                "<strong>Version: %1</strong><br>"
-                "<strong>License: GPLv2</strong><br>"
-                "<strong>Page:</strong> liquid-graphic.garage.maemo.org"
-                "<p>The <strong>%2</strong> is a graphic editor for Nokia's tablet. <br>"
-                "In our application user can control a <br>"
-                "Brush, using accelerometer or touchscreen of a tablet. <br>"
-                "<strong>Developers: </strong>"
-                "<table cellpadding=1 cellspacing=1>"
-                "<tr><td>Volkov A.A.</td> <td> (volkov@cs.karelia.ru)</td></tr>"
-                "<tr><td>Dmitriev V.V.</td> <td> (vdmitrie@cs.karelia.ru)</td></tr>"
-                "<tr><td>Kirpichonock K.N.</td><td> (kirpiche@cs.karelia.ru)</td></tr>"
-                "</table></p></div>"
-                ).arg(QCoreApplication::applicationVersion(), QCoreApplication::applicationName()));
+    QMessageBox::about(this, tr("About program"), tr(
+            "<div style='y-overflow:scroll;'>"
+            "<strong>Version: %1</strong><br>"
+            "<strong>License: GPLv2</strong><br>"
+            "<strong>Page:</strong> liquid-graphic.garage.maemo.org"
+            "<p>The <strong>%2</strong> is a funny graphic editor.<br>"
+            "In our application user can control a Brush, <br>"
+            "using accelerometer or touchscreen of a tablet. <br>"
+            "<strong>Developers: </strong>"
+            "<table cellpadding=1 cellspacing=1>"
+            "<tr><td>Volkov A.A.</td> <td> (volkov@cs.karelia.ru)</td></tr>"
+            "<tr><td>Dmitriev V.V.</td> <td> (vdmitrie@cs.karelia.ru)</td></tr>"
+            "<tr><td>Kirpichonock K.N.</td><td> (kirpiche@cs.karelia.ru)</td></tr>"
+            "</table></p></div>"
+            ).arg(QCoreApplication::applicationVersion(), QCoreApplication::applicationName()));
 }
 
 // Creates new image
@@ -239,8 +244,8 @@ bool MainWindow::saveAs() {
 // Shows exit dialog (Save, Discard, Cancel), when user close application
 bool MainWindow::showExitDialog() {
      QMessageBox msgBox;
-     msgBox.setText("The document has been modified.");
-     msgBox.setInformativeText("Do you want to save your changes?");
+     msgBox.setText(tr("The image has been modified."));
+     msgBox.setInformativeText(tr("Do you want to save your changes?"));
      msgBox.setStandardButtons(QMessageBox::Save | QMessageBox::Discard | QMessageBox::Cancel);
      msgBox.setDefaultButton(QMessageBox::Save);
 
@@ -351,5 +356,11 @@ bool MainWindow::event(QEvent *event) {
 
 void MainWindow::changeEvent(QEvent *e)
 {
-
+    switch (e->type()) {
+    case QEvent::LanguageChange:
+        ui->retranslateUi(this);
+        break;
+    default:
+        break;
+    }
 }
