@@ -39,6 +39,12 @@
 #include <QToolButton>
 #include <QContextMenuEvent>
 
+#ifdef TARGET
+#define APP_NAME TARGET
+#else
+#define APP_NAME "liquid"
+#endif
+
 namespace Ui {
     class MainWindow;
 }
@@ -86,6 +92,7 @@ private:
     //! Action for activating an accelerometer mode.
     QAction *toggleAcc;
     //! Action for creating new image.
+    QAction *langAct;
     QAction *newAct;
     //! "Open file" action for File menu.
     QAction *openAct;
