@@ -71,17 +71,17 @@ void MCE::displayStateChanged(const QDBusMessage &message)
     emit sigDisplayStateChanged(state);
 }
 
-void MCE::displayStateError(const QDBusError &error)
+void MCE::displayStateError(const QDBusError &)
 {
 
 }
 
-void MCE::setDisplayState(const QString &state)
+void MCE::setDisplayState(const QString &)
 {
-    if (!state.isEmpty()) {
-        if (state == MCE_DISPLAY_ON_STRING)
-            ;   //Display on
-        else if (state == MCE_DISPLAY_OFF_STRING)
-            ;  //Display off
-    }
+//    if (!state.isEmpty()) {
+//        if (state == MCE_DISPLAY_ON_STRING)
+//            ;  // Display on
+//        else if (state == MCE_DISPLAY_OFF_STRING)
+//            ;  // Display off
+//    }
 }
